@@ -1,4 +1,4 @@
-__version__ = "3.0.12"
+__version__ = "3.0.13"
 from janda.pururin import Pururin
 from janda.nhentai import Nhentai
 from janda.hentaifox import Hentaifox
@@ -6,4 +6,4 @@ from janda.hentai2read import Hentai2read
 from janda.simply_hentai import SimplyHentai
 from janda.qhentai import Qhentai
 from janda.asmhentai import Asmhentai
-from janda.utils import *
\ No newline at end of file
+from janda.utils.parser import resolve
\ No newline at end of file
