@@ -106,7 +106,7 @@ class Pururin(object):
         if data.json()['type'] is None:
             raise ValueError('No results found')
 
-        self.final = json.loads(Pururin.better_object(data.json()), encoding="utf-8")
+        self.final = json.loads(Pururin.better_object(data.json()))
 
         return Pururin.better_object(self.final)
 
