@@ -65,7 +65,7 @@ class Qhentai(object):
 
         data = requests.get(BASE_URL.qhentai, params=self.specs)
 
-        self.final = json.loads(better_object(data.json()), encoding="utf-8")
+        self.final = json.loads(better_object(data.json()))
    
         return better_object(self.final)
         
